@@ -1,4 +1,4 @@
-# append-css.rb: $Revision%
+# append-css.rb: $Revision: 1.5 $
 #
 # Append CSS fragment via Preferences Page.
 #
@@ -6,11 +6,15 @@
 # Distributed under the GPL
 #
 add_header_proc do
-	<<-HTML if @conf['append-css.css']
-	<style>
-	#{CGI::escapeHTML( @conf['append-css.css'] )}
-	</style>
-	HTML
+	if @conf['append-css.css'] and @conf['append-css.css'].length > 0 then
+		<<-HTML if @conf['append-css.css']
+		<style type="text/css"><!--
+		#{@conf['append-css.css']}
+		--></style>
+		HTML
+	else
+		''
+	end
 end
 
 unless @resource_loaded then
