@@ -1,4 +1,4 @@
-# category.rb $Revision: 1.19 $
+# category.rb $Revision: 1.21 $
 #
 # Copyright (c) 2003 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -45,7 +45,7 @@ def category_anchor(category)
 	period_string = 
 		case period
 		when "month"
-			"year=#{@date.year};month=#{@date.month};"
+			"year=#{@date.year};month=#{'%02d' % @date.month};"
 		when "quarter"
 			"year=#{@date.year};month=#{(@date.month - 1) / 3 + 1}Q;"
 		when "half"
@@ -568,7 +568,7 @@ end # module Category
 		ret << "#{@category_conf_label}:\n"
 		@categories.each do |c|
 			e_c = CGI.escapeHTML(c)
-			ret << %Q!| <a href="javascript:inj_c(&quot;[#{e_c}] &quot;)">#{e_c}</a>\n!
+			ret << %Q!| <a href="javascript:inj_c(&quot;[#{e_c}]&quot;)">#{e_c}</a>\n!
 		end
 		ret << "|\n</div>\n<br>\n"
 	end
