@@ -1,4 +1,4 @@
-# image.rb $Revision: 1.22 $
+# image.rb $Revision: 1.23.2.1 $
 # -pv-
 # 
 # ̾:
@@ -11,13 +11,15 @@
 # ʸ
 #
 # Ȥ:
-# image( number, 'altword', thumbnail ) - ɽޤ
+# image( number, 'altword', thumbnail, size, place ) - ɽޤ
 #    number - ֹ012
 #    altword - img altʸ
 #    thumbnail - ͥ(ʲ)ꤹ(ά)
+#    size - Υ(Array)[width, height]ηǻ(ά)
+#    place - imgclass̾(ά)ά'photo'
 #
-# image_left( number, 'altword', thumbnail ) - imageclass=leftɲäޤ
-# image_right( number, 'altword', thumbnail ) - imageclass=rightɲäޤ
+# image_left( number, 'altword', thumbnail, size ) - imageclass=leftɲäޤ
+# image_right( number, 'altword', thumbnail, size ) - imageclass=rightɲäޤ
 #
 # image_link( number, 'desc' ) - ؤΥ󥯤ޤ
 #    number - ֹ012
@@ -78,10 +80,10 @@ end
 def image( id, alt = 'image', thumbnail = nil, size = nil, place = 'photo' )
 	if @conf.secure then
 		image = "#{@image_date}_#{id}.jpg"
-		image_t = "#{@image_date}_#{thumbnail}.jpg" unless thumbnail
+		image_t = "#{@image_date}_#{thumbnail}.jpg" if thumbnail
 	else
    	image = image_list( @image_date )[id.to_i]
-   	image_t = image_list( @image_date )[thumbnail.to_i]
+   	image_t = image_list( @image_date )[thumbnail.to_i] if thumbnail
 	end
 	if size then
 		if size.kind_of?(Array)
@@ -156,7 +158,8 @@ def image_info( f )
 			break if data[1] == 0xD9
 
 			data_size = data[2,2].unpack( 'n' ).first + 2
-			if data[1] == 0xC0
+			case data[1]
+			when 0xc0, 0xc1, 0xc2, 0xc3, 0xc5, 0xc6, 0xc7, 0xc9, 0xca, 0xcb, 0xcd, 0xce, 0xcf
 				image_width, image_height = data[5,4].unpack('nn')
 				break
 			else
@@ -267,7 +270,7 @@ add_form_proc do |date|
 		</script>
 		]
 		case @conf.style.sub( /^blog/i, '' )
-		when /^wiki$/i
+                when /^wiki|markdown$/i
 			ptag1 = "{{"
 			ptag2 = "}}"
 		when /^rd$/i
