@@ -1,5 +1,5 @@
 =begin
-= ŷץ饰((-$Id: weather.rb,v 1.5 2004/05/15 05:44:51 zunda Exp $-))
+= ŷץ饰((-$Id: weather.rb,v 1.6 2004/08/10 18:28:42 zunda Exp $-))
 ŷ򡢤ǽ˹˼¸줾
 ξɽޤ
 
@@ -370,6 +370,14 @@ def weather_configure_html( conf )
 		<option value="false"#{' selected'unless conf['weather.show_mobile']}>
 		äˤϺŷɽʤ
 	</select></p>
+	<h4>󥸥ʤɤΥܥåȤؤɽ</h4>
+	<p>Ǥ</p>
+	<p><select name="weather.show_robot">
+		<option value="true"#{' selected'if conf['weather.show_robot']}>
+		󥸥ʤɤΥܥåȤˤ⺣ŷΤ餻
+		<option value="false"#{' selected'unless conf['weather.show_robot']}>
+		󥸥ʤɤΥܥåȤˤϺŷΤ餻ʤ
+	</select></p>
 	<h4>¾</h4>
 	<p>¾ˤ⤤Ĥtdiary.confǤܤޤ
 		ܤϡץ饰Υե(weather.rb)</p>
