@@ -132,11 +132,6 @@ def mobile_label_hidden_diary; 'ϡɽۤǤ'; end
 # category
 #
 def category_anchor(c); "[#{c}]"; end
-def category_title; "ƥ"; end
-def category_title_year(year); "#{year}ǯ"; end
-def category_title_month(year, month); "#{year}ǯ#{month}"; end
-def category_title_quarter(year, q); "#{year}ǯ#{q}Q"; end
-def category_title_latest; ""; end
 
 #
 # preferences (resources)
@@ -200,6 +195,8 @@ add_conf_proc( 'display', 'ɽ' ) do
 	HTML
 end
 
+@theme_location_comment = "<p>ˤʤơޤ<a href=\"http://www.tdiary.org/20021001.html\">ơޡ꡼</a>Ǥޤ</p>"
+
 add_conf_proc( 'theme', 'ơ' ) do
 	saveconf_theme
 
@@ -217,7 +214,7 @@ add_conf_proc( 'theme', 'ơ' ) do
 	</select>
 	<input name="css" size="50" value="#{ @conf.css }">
 	</p>
-	#{"<p>ˤʤơޤ<a href=\"http://www.tdiary.org/20021001.html\">ơޡ꡼</a>Ǥޤ</p>" unless @conf.mobile_agent?}
+	#{@theme_location_comment unless @conf.mobile_agent?}
 	HTML
 end
 
