@@ -1,13 +1,13 @@
 =begin
 == NAME
 tDiary: the "tsukkomi-able" web diary system.
-tdiary.rb $Revision: 1.193 $
+tdiary.rb $Revision: 1.195.2.2 $
 
-Copyright (C) 2001-2004, TADA Tadashi <sho@spc.gr.jp>
+Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
 You can redistribute it and/or modify it under GPL2.
 =end
 
-TDIARY_VERSION = '2.0.0'
+TDIARY_VERSION = '2.0.1'
 
 require 'cgi'
 begin
@@ -57,7 +57,7 @@ class CGI
 	end
 
 	def mobile_agent?
-		self.user_agent =~ %r[(DoCoMo|J-PHONE|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode)]i
+		self.user_agent =~ %r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode)]i
 	end
 end
 
@@ -429,7 +429,7 @@ module TDiary
 		end
 
 		def mobile_agent?
-			%r[(DoCoMo|J-PHONE|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode)]i =~ ENV['HTTP_USER_AGENT']
+			%r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode)]i =~ ENV['HTTP_USER_AGENT']
 		end
 
 		def bot?
@@ -894,7 +894,7 @@ module TDiary
 				}.join
 				r = ERbLight::new( rhtml.untaint ).result( binding )
 				r = ERbLight::new( r ).src
-				store_cache( r, prefix )
+				store_cache( r, prefix ) unless @diaries.empty?
 			end
 
 			# apply plugins
@@ -1615,7 +1615,7 @@ module TDiary
 		attr_reader :last_modified
 		def initialize(cgi, rhtml, conf)
 			super
-			@last_modified = Time.at(0)
+			@last_modified = Time.now
 		end
 	end
 
